@@ -248,6 +248,21 @@ def validate(message, **config):
         return False
 
 
+def validate_signed_by(message, signer, **config):
+    """ Validate that a message was signed by a particular certificate.
+
+    This works much like ``validate(...)``, but additionally accepts a
+    ``signer`` argument.  It will reject a message for any of the regular
+    circumstances, but will also reject it if its not signed by a cert with the
+    argued name.
+    """
+
+    config = copy.deepcopy(config)
+    config['routing_nitpicky'] = True
+    config['routing_policy'] = {message['topic']: [signer]}
+    return validate(message, **config)
+
+
 def strip_credentials(message):
     """ Strip credentials from a message dict.
 
